@@ -10,19 +10,11 @@ import json
 import os
 
 from django.conf import settings
-from django.core.management.base import BaseCommand
 
-from django_cfg.modules.django_logging import get_logger
-
-logger = get_logger('show_config')
+from django_cfg.management.utils import SafeCommand
 
 
-class Command(BaseCommand):
-    # Web execution metadata
-    web_executable = True
-    requires_input = False
-    is_destructive = False
-
+class Command(SafeCommand):
     help = 'Show Django Config configuration'
 
     def add_arguments(self, parser):
@@ -40,23 +32,23 @@ class Command(BaseCommand):
 
     def handle(self, *args, **options):
         """Show configuration in requested format."""
-        logger.info("Starting show_config command")
+        self.logger.info("Starting show_config command")
         try:
             # Get the config instance from Django settings
             config = self._get_config_instance()
-            logger.info("Successfully retrieved configuration instance")
+            self.logger.info("Successfully retrieved configuration instance")
 
             if options['format'] == 'json':
-                logger.info("Displaying configuration in JSON format")
+                self.logger.info("Displaying configuration in JSON format")
                 self._show_json_format(config, options['include_secrets'])
             else:
-                logger.info("Displaying configuration in table format")
+                self.logger.info("Displaying configuration in table format")
                 self._show_table_format(config, options['include_secrets'])
 
-            logger.info("show_config command completed successfully")
+            self.logger.info("show_config command completed successfully")
         except Exception as e:
             error_msg = f'Failed to show configuration: {e}'
-            logger.error(error_msg, exc_info=True)
+            self.logger.error(error_msg, exc_info=True)
             self.stdout.write(
                 self.style.ERROR(f'❌ {error_msg}')
             )
