@@ -254,3 +254,114 @@ class ImageField(FieldConfig):
             config['caption_template'] = self.caption_template
         config['alt_text'] = self.alt_text
         return config
+
+
+class MarkdownField(FieldConfig):
+    """
+    Markdown documentation widget configuration.
+
+    Renders markdown content from field value or external file with beautiful styling.
+    Auto-detects whether content is a file path or markdown string.
+
+    Examples:
+        # From model field (markdown string)
+        MarkdownField(
+            name="description",
+            title="Documentation",
+            collapsible=True
+        )
+
+        # From file path field
+        MarkdownField(
+            name="docs_path",
+            title="User Guide",
+            collapsible=True,
+            default_open=True
+        )
+
+        # Static file (same for all objects)
+        MarkdownField(
+            name="static_doc",  # method that returns file path
+            title="API Documentation",
+            source_file="docs/api.md",  # relative to app root
+            max_height="500px"
+        )
+
+        # Dynamic markdown with custom title
+        MarkdownField(
+            name="get_help_text",  # method that generates markdown
+            title="Help",
+            collapsible=True,
+            enable_plugins=True
+        )
+    """
+
+    ui_widget: Literal["markdown"] = "markdown"
+
+    # Display options
+    collapsible: bool = Field(True, description="Wrap in collapsible details/summary")
+    default_open: bool = Field(False, description="Open by default if collapsible")
+    max_height: Optional[str] = Field("500px", description="Max height with scrolling (e.g., '500px', None for no limit)")
+
+    # Content source
+    source_file: Optional[str] = Field(
+        None,
+        description="Static file path relative to app root (e.g., 'docs/api.md')"
+    )
+    source_field: Optional[str] = Field(
+        None,
+        description="Alternative field name for content (defaults to 'name' field)"
+    )
+
+    # Markdown options
+    enable_plugins: bool = Field(
+        True,
+        description="Enable mistune plugins (tables, strikethrough, task lists, etc.)"
+    )
+
+    # Custom icon for collapsible header
+    header_icon: Optional[str] = Field(
+        "description",
+        description="Material icon for collapsible header"
+    )
+
+    def get_widget_config(self) -> Dict[str, Any]:
+        """Extract markdown widget configuration."""
+        config = super().get_widget_config()
+        config['collapsible'] = self.collapsible
+        config['default_open'] = self.default_open
+        config['max_height'] = self.max_height
+        config['enable_plugins'] = self.enable_plugins
+
+        if self.source_file is not None:
+            config['source_file'] = self.source_file
+        if self.source_field is not None:
+            config['source_field'] = self.source_field
+        if self.header_icon is not None:
+            config['header_icon'] = self.header_icon
+
+        return config
+
+
+class ShortUUIDField(FieldConfig):
+    """
+    Short UUID widget configuration for displaying shortened UUIDs.
+
+    Examples:
+        ShortUUIDField(name="id", length=8)
+        ShortUUIDField(name="uuid", length=12, copy_on_click=True)
+    """
+
+    ui_widget: Literal["short_uuid"] = "short_uuid"
+
+    length: int = Field(8, description="Number of characters to display from UUID")
+    copy_on_click: bool = Field(True, description="Enable click-to-copy functionality")
+    show_full_on_hover: bool = Field(True, description="Show full UUID in tooltip on hover")
+
+    def get_widget_config(self) -> Dict[str, Any]:
+        """Extract short UUID widget configuration."""
+        config = super().get_widget_config()
+        config['length'] = self.length
+        config['copy_on_click'] = self.copy_on_click
+        config['show_full_on_hover'] = self.show_full_on_hover
+        return config
